{ config, pkgs, ... }:

let
  user = "elnu";
in
{
  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  home = {
    # Home Manager needs a bit of information about you and the
    # paths it should manage.
    username = "${user}";
    homeDirectory = "/home/${user}";

    # This value determines the Home Manager release that your
    # configuration is compatible with. This helps avoid breakage
    # when a new Home Manager release introduces backwards
    # incompatible changes.
    #
    # You can update Home Manager without changing this value. See
    # the Home Manager release notes for a list of state version
    # changes in each release.
    stateVersion = "22.05";

    packages = with pkgs; [
      # Command line utilities
      wget
      neofetch
      vim
      ranger
      trash-cli # aliased to rm in .bashrc

      # GUI applications
      firefox
    ];

    file = {
      ".bashrc" = {
        source = ./.bashrc;
      };
    };

    sessionVariables = {
      EDITOR = "vim";
    };
  };
}
